@@ -1,14 +1,21 @@
 import os
 
-import setuptools
+import pkg_resources, setuptools
 
+import pyflakes
 from pyflakes import checker
 
-import compiler, sys
+import sys
 
 def check(codeString, filename):
     try:
-        tree = compiler.parse(codeString)
+        if pkg_resources.parse_version(pyflakes.__version__) >= (0,5,0):
+            import _ast
+            tree = compile(codeString, filename, "exec", _ast.PyCF_ONLY_AST)
+        else:
+            import compiler
+            # for pyflakes < 0.5
+            tree = compiler.parse(codeString)
     except (SyntaxError, IndentationError):
         value = sys.exc_info()[1]
         try:
